# Plan
Here's a checklist of my immediate plans for the future. If you have an idea for a feature, feel free to make an issue.

## v1.3.1
* [x] Improve star background.
	* [x] Create star textures.
	* [x] Render these textures instead of points.
		* [x] Get started.
		* [x] Set each star to a random layer.
		* [x] Use additive blending.
	* [x] Polishes.
	* [x] Try enabling multi-sampling for stars and see if it's better.
	* [x] Ensure stars are nicely wrapped around or removed at the edges now that they aren't just pixels.
		* [x] Have stars rendered at their centres.
		* [x] Calculate the star bounding box dimensions during asset generation.
		* [x] Use these sizes to appropriately wrap them around.
	* [ ] ~Maybe fix problem with stars moving faster when zoomed out and moving the camera while spectating.~
		Just camera speed differences, nothing else.
	* [ ] ~Alpha/intensity refactor now that additive blending is used.~
		Nevermind, this change actually increases flicker.
* [x] Add decorative background clouds as well as the stars.
	* [x] Perlin noise.
	* [x] Make it look better.
		* [x] Get started.
		* [x] Polishes.
	* [x] Add it to the game.
	* [x] Generate three images.
	* [x] Refactor how the z-coordinate is handled for star rendering.
		* [x] Get started.
		* [x] Figure out slow camera speed when zoomed out.
		* [x] Ensure that wrapping works by increasing the star size.
	* [x] Get a single clouds image moving.
	* [x] Use a texture array for the different cloud images.
	* [x] Get parallax with multiple clouds working.
	* [x] Change the brightness of the clouds based on the distance to the camera.
	* [x] Get multiple colour channels and figure out the best way to add colour.
	* [x] Add support for arbitrary gradients with a buffer texture to store the colour data.
		Will only implement a Bézier curve, but this is flexible for any arbitrary gradient.
	* [x] Ensure that the stars are coloured similarly to the clouds.
		* [x] Get started with basic framebuffer code.
		* [x] Have things work when the window resizes.
	* [x] Try varying the way clouds are generated for different layers.
	* [x] Try increasing the power in cloud generation.
	* [x] Use a Bézier curve for the gradient.
* [x] Update settings with options for decorative clouds.
	* [x] Add customisation to config schema.
		* [x] Gradients.
			Will support arbitrary Bézier curves at this point.
		* [x] All other shader parameters.
			* [x] Cloud brightness.
			* [x] Star intensity.
			* [x] Star colour brightness and offset.
	* [x] Create GUI to tweak this customisation. This will include many default presets and a custom option.
		* [x] Create simple GUI to choose a fixed sky preset.
		* [x] Get working on tweaking the custom sky in the GUI.
			* [x] Add "Custom" option to combo box.
			* [x] Gradients.
				* [x] Get started.
				* [x] Fix things.
				* [x] Close gradients colour pickers when pressing escape.
				* [x] Allow gradient points to be added and removed.
				* [x] Appropriately update gradient colour pickers during addition/removal.
			* [x] Everything else.
	* [x] Custom preset changes.
		* [x] Save the custom preset when changing to an existing preset temporarily.
		* [x] Allow replacing the custom preset with an existing one with a button.
	* [x] Use one-variant enum for Bézier gradients in case of future extension.
	* [x] Allow reducing graphics quality for possible performance gains.
		* [x] Complete disabling of clouds.
		* [x] Complete disabling of stars.
		* [x] Framebuffer settings.
			* [x] Allow complete disabling, using a 1x1 texture whose colour is determined by the gradient average.
			* [x] Fix problems with cloud brightness without framebuffer.
			* [x] Try and remove problems with `u8` framebuffer and always use it.
			* [ ] ~If the above's not possible, allow changing framebuffer format to u8 instead of f16 (some hardware might prefer that, maybe).~
		* [x] Try and decrease the brightness of the 1x1 texture when zooming out.
		* [x] Add label explaining what disabling the framebuffer does.
* [x] Other graphics improvements.
	* [x] Have all texture sizes 256px per world unit.
	* [x] Improve block texture, including adding transparency.
		* [x] Get alpha channel working.
		* [x] Start improving the texture.
		* [x] Implement a border that surrounds the edges of blocks.
			* [x] Prepare block sections to include borders.
			* [x] Modify mesh generation code to generate border.
			* [x] Render border.
			* [x] Use a solid colour border with less width.
				* [x] Corner pieces.
					* [x] Get started.
					* [x] Fix bug.
				* [x] Edges.
			* [x] Make the border a gradient.
				* [x] Corners.
				* [x] Edges.
			* [x] Test that things work on varying block sizes.
		* [x] Polishes.
		* [x] Think about block render order.
			* [x] Player.
				Blocks over players is fine.
			* [x] Special areas now that things can look ugly when the area under a block is still visible because of transparency.
				Might use a stencil buffer somehow.
	* [x] Change world border RGBA colour.
	* [x] Tweak special area alpha vs intensity.
* [x] Add more sky presets.
* [x] Fix bug with death effect not showing when eliminating a player.
* [x] Fix bug with scores text permanently wrapping when the window is resized to be sufficiently small.
* [x] Add keyboard shortcut to hide the HUD.
* [x] Print to stdout the process of asset generation.
* [x] Allow varying the number of cloud layers rendered.
* [ ] Update metainfo.
	* [ ] Add author information.

## v1.4.0
* [ ] Add extension data to protocol.
* [ ] Update SERP version.
